@@ -709,12 +709,14 @@ sub regenerate_readme_md {
                     $image_uri->path("/users/$user_name/repos/$user_name+$repository_name/heads/$branch/status.svg");
                     push @badges, "[![Kritika Status]($image_uri)]($build_uri)";
                 } elsif ($service_name =~ m!^github-actions(?:/(.+))?$!) {
-                    my $workflow_file = $1 || 'test';
-                    if ($workflow_file =~ /\.(?:yml|yaml)$/) {
-                        push @badges, "[![Actions Status](https://github.com/$user_name/$repository_name/actions/workflows/$workflow_file/badge.svg)](https://github.com/$user_name/$repository_name/actions)";
-                    } else {
-                        push @badges, "[![Actions Status](https://github.com/$user_name/$repository_name/workflows/$workflow_file/badge.svg)](https://github.com/$user_name/$repository_name/actions)";
+                    # ref. https://docs.github.com/en/actions/how-tos/monitor-workflows/add-a-status-badge
+                    my $workflow_file = $1 || 'test.yml';
+                    if ($workflow_file !~ /\.(?:yml|yaml)$/) {
+                        $workflow_file .= '.yml';
                     }
+                    my $workflow_name = $workflow_file;
+                    $workflow_name =~ s/\.ya?ml$//;
+                    push @badges, "[![Actions Status](https://github.com/$user_name/$repository_name/actions/workflows/$workflow_file/badge.svg?branch=$branch)](https://github.com/$user_name/$repository_name/actions?workflow=$workflow_name)";
                 } elsif ($service_name eq 'gitlab-pipeline') {
                     push @badges, "[![Gitlab pipeline](https://gitlab.com/$user_name/$repository_name/badges/$branch/pipeline.svg)](https://gitlab.com/$user_name/$repository_name/-/commits/$branch)";
                 } elsif ($service_name eq 'gitlab-coverage') {
